@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::FinderCode;
+package Dist::Zilla::Plugin::FinderCode 6.007;
 # ABSTRACT: a callback-based FileFinder plugin
-$Dist::Zilla::Plugin::FinderCode::VERSION = '5.043';
+
 use Moose;
 with 'Dist::Zilla::Role::FileFinder';
 
@@ -57,11 +57,11 @@ Dist::Zilla::Plugin::FinderCode - a callback-based FileFinder plugin
 
 =head1 VERSION
 
-version 5.043
+version 6.007
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
