@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MakeMaker::Runner;
+package Dist::Zilla::Plugin::MakeMaker::Runner 6.007;
 # ABSTRACT: Test and build dists with a Makefile.PL
-$Dist::Zilla::Plugin::MakeMaker::Runner::VERSION = '5.043';
+
 use Moose;
 with(
   'Dist::Zilla::Role::BuildRunner',
@@ -73,11 +73,11 @@ Dist::Zilla::Plugin::MakeMaker::Runner - Test and build dists with a Makefile.PL
 
 =head1 VERSION
 
-version 5.043
+version 6.007
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
