@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::PkgVersion;
+package Dist::Zilla::Plugin::PkgVersion 6.007;
 # ABSTRACT: add a $VERSION to your packages
-$Dist::Zilla::Plugin::PkgVersion::VERSION = '5.043';
+
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -57,6 +57,14 @@ use namespace::autoclean;
 #pod C<die_on_line_insertion> is true, PkgVersion will raise an exception rather
 #pod than insert a new line.
 #pod
+#pod =attr use_package
+#pod
+#pod This option, if true, will not insert an assignment to C<$VERSION> but will
+#pod replace the existing C<package> declaration with one that includes a version
+#pod like:
+#pod
+#pod   package Module::Name 0.001;
+#pod
 #pod =attr use_our
 #pod
 #pod The idea here was to insert C<< { our $VERSION = '0.001'; } >> instead of C<<
@@ -95,6 +103,10 @@ sub BUILD {
   my ($self) = @_;
   $self->log("use_our option to PkgVersion is deprecated and will be removed")
     if $self->use_our;
+
+  if ($self->use_package && ($self->use_our || $self->use_begin)) {
+    $self->log_fatal("use_package and (use_our or use_begin) are not compatible");
+  }
 }
 
 sub munge_files {
@@ -131,6 +143,12 @@ has die_on_line_insertion => (
   default => 0,
 );
 
+has use_package => (
+  is  => 'ro',
+  isa => 'Bool',
+  default => 0,
+);
+
 has use_our => (
   is  => 'ro',
   isa => 'Bool',
@@ -172,7 +190,7 @@ sub munge_perl {
   my %seen_pkg;
 
   my $munged = 0;
-  for my $stmt (@$package_stmts) {
+  STATEMENT: for my $stmt (@$package_stmts) {
     my $package = $stmt->namespace;
     if ($seen_pkg{ $package }++) {
       $self->log([ 'skipping package re-declaration for %s', $package ]);
@@ -190,6 +208,17 @@ sub munge_perl {
     $self->log("non-ASCII version is likely to cause problems")
       if $version =~ /\P{ASCII}/;
 
+    if ($self->use_package) {
+      my $perl = sprintf 'package %s %s;', $package, $version;
+      $perl .= ' # TRIAL' if $self->zilla->is_trial;
+
+      my $newstmt = PPI::Token::Unknown->new($perl);
+      Carp::carp("error inserting version in " . $file->name)
+        unless $stmt->parent->__replace_child($stmt, $newstmt);
+      $munged = 1;
+      next STATEMENT;
+    }
+
     # the \x20 hack is here so that when we scan *this* document we don't find
     # an assignment to version; it shouldn't be needed, but it's been annoying
     # enough in the past that I'm keeping it here until tests are better
@@ -237,7 +266,7 @@ sub munge_perl {
 
     $perl = $blank ? "$perl\n" : "\n$perl";
 
-    (my $clean_version = $version) =~ tr/_//d;
+    my $clean_version = $version =~ tr/_//dr;
     $perl .= (
       $self->use_our
         ? "\n\$VERSION\x20=\x20'$clean_version';"
@@ -267,8 +296,12 @@ sub munge_perl {
     $munged = 1;
   }
 
-  # the document is no longer correct; it must be reparsed before it can be used again
-  $file->encoded_content($document->serialize) if $munged;
+  # the document is no longer correct; it must be reparsed before it can be
+  # used again, so we can't just save_ppi_document_to_file
+  # Maybe we want a way to clear the cache for the old form, though...
+  # -- rjbs, 2016-04-24
+  $file->content($document->serialize) if $munged;
+  return;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -299,7 +332,7 @@ Dist::Zilla::Plugin::PkgVersion - add a $VERSION to your packages
 
 =head1 VERSION
 
-version 5.043
+version 6.007
 
 =head1 SYNOPSIS
 
@@ -348,6 +381,14 @@ will have different line numbers (off by one) than the source.  If
 C<die_on_line_insertion> is true, PkgVersion will raise an exception rather
 than insert a new line.
 
+=head2 use_package
+
+This option, if true, will not insert an assignment to C<$VERSION> but will
+replace the existing C<package> declaration with one that includes a version
+like:
+
+  package Module::Name 0.001;
+
 =head2 use_our
 
 The idea here was to insert C<< { our $VERSION = '0.001'; } >> instead of C<<
@@ -393,7 +434,7 @@ numbers using C<our $VERSION = '...';> and without changing line numbers
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
