@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::RemovePrereqs;
+package Dist::Zilla::Plugin::RemovePrereqs 6.007;
 # ABSTRACT: a plugin to remove gathered prereqs
-$Dist::Zilla::Plugin::RemovePrereqs::VERSION = '5.043';
+
 use Moose;
 with 'Dist::Zilla::Role::PrereqSource';
 
@@ -85,7 +85,7 @@ Dist::Zilla::Plugin::RemovePrereqs - a plugin to remove gathered prereqs
 
 =head1 VERSION
 
-version 5.043
+version 6.007
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,7 @@ L<AutoPrereqs|Dist::Zilla::Plugin::AutoPrereqs>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
