@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::UploadToCPAN;
+package Dist::Zilla::Plugin::UploadToCPAN 6.007;
 # ABSTRACT: upload the dist to CPAN
-$Dist::Zilla::Plugin::UploadToCPAN::VERSION = '5.043';
+
 use Moose;
 with qw(Dist::Zilla::Role::BeforeRelease Dist::Zilla::Role::Releaser);
 
@@ -52,6 +52,14 @@ use namespace::autoclean;
   }
 }
 
+#pod =attr credentials_stash
+#pod
+#pod This attribute holds the name of a L<PAUSE stash|Dist::Zilla::Stash::PAUSE>
+#pod that will contain the credentials to be used for the upload.  By default,
+#pod UploadToCPAN will look for a C<%PAUSE> stash.
+#pod
+#pod =cut
+
 has credentials_stash => (
   is  => 'ro',
   isa => 'Str',
@@ -276,7 +284,7 @@ Dist::Zilla::Plugin::UploadToCPAN - upload the dist to CPAN
 
 =head1 VERSION
 
-version 5.043
+version 6.007
 
 =head1 SYNOPSIS
 
@@ -305,6 +313,12 @@ You can't put your password in your F<dist.ini>.  C'mon now!
 
 =head1 ATTRIBUTES
 
+=head2 credentials_stash
+
+This attribute holds the name of a L<PAUSE stash|Dist::Zilla::Stash::PAUSE>
+that will contain the credentials to be used for the upload.  By default,
+UploadToCPAN will look for a C<%PAUSE> stash.
+
 =head2 username
 
 This option supplies the user's PAUSE username.
@@ -347,7 +361,7 @@ is not recommended in most cases.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
