@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::PluginBundle;
+package Dist::Zilla::Role::PluginBundle 6.007;
 # ABSTRACT: something that bundles a bunch of plugins
-$Dist::Zilla::Role::PluginBundle::VERSION = '5.043';
+
 use Moose::Role;
 
 use namespace::autoclean;
@@ -36,7 +36,7 @@ Dist::Zilla::Role::PluginBundle - something that bundles a bunch of plugins
 
 =head1 VERSION
 
-version 5.043
+version 6.007
 
 =head1 DESCRIPTION
 
@@ -47,7 +47,7 @@ configure the bundle.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
