@@ -1,6 +1,6 @@
-package Dist::Zilla::Stash::Mint;
+package Dist::Zilla::Stash::Mint 6.007;
 # ABSTRACT: a stash of your default minting provider/profile
-$Dist::Zilla::Stash::Mint::VERSION = '5.043';
+
 use Moose;
 with 'Dist::Zilla::Role::Stash';
 
@@ -35,11 +35,11 @@ Dist::Zilla::Stash::Mint - a stash of your default minting provider/profile
 
 =head1 VERSION
 
-version 5.043
+version 6.007
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
